@@ -81,6 +81,7 @@ from cardinal_pythonlib.sqlalchemy.session import (
     get_engine_from_session,
     get_safe_url_from_engine,
     get_safe_url_from_session,
+    SQLITE_MEMORY_URL,
 )
 from cardinal_pythonlib.sqlalchemy.table_identity import TableIdentity
 
@@ -88,8 +89,6 @@ log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 log = BraceStyleAdapter(log)
 
-SQLITE_MEMORY_URL = "sqlite://"
-
 
 # =============================================================================
 # TableDependency; get_all_dependencies
@@ -393,6 +392,7 @@ class TranslationContext(object):
                  dst_session: Session,
                  src_engine: Engine,
                  dst_engine: Engine,
+                 src_table_names: List[str],
                  missing_src_columns: List[str] = None,
                  info: Dict[str, Any] = None) -> None:
         self.oldobj = oldobj
@@ -404,6 +404,7 @@ class TranslationContext(object):
         self.dst_session = dst_session
         self.src_engine = src_engine
         self.dst_engine = dst_engine
+        self.src_table_names = src_table_names
         self.missing_src_columns = missing_src_columns or []  # type: List[str]
         self.info = info or {}  # type: Dict[str, Any]
 
@@ -590,6 +591,8 @@ def merge_db(base_class: Type,
         tables,
         extra_dependencies=[td.sqla_tuple() for td in extra_table_dependencies]
     )
+    # Note that the ordering is NOT NECESSARILY CONSISTENT, though (in that
+    # the order of stuff it doesn't care about varies across runs).
     all_dependencies = get_all_dependencies(metadata, extra_table_dependencies)
     dep_classifications = classify_tables_by_dependency_type(
         metadata, extra_table_dependencies)
@@ -625,6 +628,7 @@ def merge_db(base_class: Type,
                                 src_engine=src_engine,
                                 dst_engine=dst_engine,
                                 missing_src_columns=missing_columns,
+                                src_table_names=src_tables,
                                 info=trcon_info)
         translate_fn(tc)
         if tc.newobj is None:
