@@ -23,7 +23,9 @@
 
 from typing import TYPE_CHECKING
 import logging
+import os
 
+from sqlalchemy.engine import create_engine
 from sqlalchemy.engine.base import Engine
 from sqlalchemy.engine.url import make_url
 from sqlalchemy.orm.session import Session
@@ -35,6 +37,35 @@ log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 
 
+# =============================================================================
+# Database URLs
+# =============================================================================
+
+SQLITE_MEMORY_URL = "sqlite://"
+
+
+def make_mysql_url(username: str, password: str, dbname: str,
+                   driver: str = "mysqldb", host: str = "localhost",
+                   port: int = 3306, charset: str = "utf8") -> str:
+    return "mysql+{driver}://{u}:{p}@{host}:{port}/{db}?charset={cs}".format(
+        driver=driver,
+        host=host,
+        port=port,
+        db=dbname,
+        u=username,
+        p=password,
+        cs=charset,
+    )
+
+
+def make_sqlite_url(filename: str) -> str:
+    absfile = os.path.abspath(filename)
+    return "sqlite://{host}/{path}".format(host="", path=absfile)
+    # ... makes it clear how it works! Ends up being sqlite:////abspath
+    # or sqlite:///relpath. Also works with backslashes for Windows paths; see
+    # http://docs.sqlalchemy.org/en/latest/core/engines.html#sqlite
+
+
 # =============================================================================
 # Connection management
 # =============================================================================
@@ -64,3 +95,8 @@ def get_safe_url_from_session(dbsession: Session) -> str:
     Gets a URL from a Session, obscuring the password.
     """
     return get_safe_url_from_engine(get_engine_from_session(dbsession))
+
+
+def get_safe_url_from_url(url: str) -> str:
+    engine = create_engine(url)
+    return get_safe_url_from_engine(engine)
