@@ -21,7 +21,7 @@
 ===============================================================================
 """
 
-VERSION = '1.0.9'
+VERSION = '1.0.10'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -62,7 +62,7 @@ First started in 2009.
 - ... to 1.0.8, 2017-11-29.
   Similarly.
   
-- 1.0.9, 2018-01-05 + 2018-02-19
+- 1.0.9 to 1.0.10, 2018-01-05 + 2018-02-19
   Additions to datetimefunc.py and improvements to sqlalchemy/dump.py for 
   CamCOPS. Addition of slurm.py.
 
